package com.ruoyi.web.controller.system;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.PoCollection;
import com.ruoyi.system.service.IPoCollectionService;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 藏品 信息操作处理
 *
 * @author ruoyi
 */
@RestController
@RequestMapping("/collections")
public class PoCollectionController extends BaseController {
    @Autowired
    private IPoCollectionService collectionService;

    /**
     * 获取藏品列表
     */
    @PreAuthorize("@ss.hasPermi('system:collection:list')")
    @GetMapping("/list")
    public TableDataInfo list(PoCollection poCollection)
    {
        startPage();
        List<PoCollection> list = collectionService.selectPoCollectionList(poCollection);
        return getDataTable(list);
    }

    /**
     * 获取藏品列表
     */
    @PreAuthorize("@ss.hasPermi('system:collection:export')")
    @Log(title = "获取藏品列表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, PoCollection poCollection)
    {
        List<PoCollection> list = collectionService.selectPoCollectionList(poCollection);
        ExcelUtil<PoCollection> util = new ExcelUtil<PoCollection>(PoCollection.class);
        util.exportExcel(response, list, "藏品数据");
    }

    /**
     * 根据藏品编号获取详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:collection:query')")
    @GetMapping(value = "/{collectionId}")
    public AjaxResult getInfo(@PathVariable("collectionId") Long collectionId)
    {
        return success(collectionService.selectCollectionById(collectionId));
    }

    /**
     * 新增藏品
     */
    @PreAuthorize("@ss.hasPermi('collection:add')")
    @Log(title = "藏品", businessType = BusinessType.INSERT)
    @ApiOperation("添加藏品")
    @PostMapping
    public AjaxResult add(@Validated @RequestBody PoCollection collection) {
        List<PoCollection> collectionList = collectionService.selectPoCollectionList(collection);
        if (collectionList != null && !collectionList.isEmpty())
            return error("重复的藏品");
        return toAjax(collectionService.insertCollection(collection));
    }

    /**
     * 修改藏品
     */
    @PreAuthorize("@ss.hasPermi('collection:edit')")
    @Log(title = "藏品", businessType = BusinessType.UPDATE)
    @ApiOperation("编辑藏品")
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody PoCollection collection) {
        PoCollection collection1 = collectionService.selectCollectionById(collection.getCollectionId());
        if (collection1 == null)
            return error("要修改的藏品不存在");
        if (collection1.getCochain() == 0)
            return error("要修改的藏品已上链");
        collection.setUpdateBy(getUsername());
        return toAjax(collectionService.updateCollection(collection));
    }

    /**
     * 删除藏品
     */
    @PreAuthorize("@ss.hasPermi('system:collection:remove')")
    @Log(title = "删除藏品", businessType = BusinessType.DELETE)
    @DeleteMapping("/{collectionIds}")
    public AjaxResult remove(@PathVariable Long[] collectionIds)
    {
        return toAjax(collectionService.deletePoCollectionByCollectionIds(collectionIds));
    }
}
